parse_rtp

Function parse_rtp 

pub fn parse_rtp(data: &[u8]) -> Option<(RtpHeader, &[u8])>
Parse an RTP packet header and return the payload type and payload data.

Returns None if the packet is too short or malformed.